---
hide: toc
---

# Documentation for ifes_apt_tc_data_modeling

A Python software module for reading file formats that are used in the research field of atom probe tomography and field ion microscopy.

<div markdown="block" class="home-grid">
<div markdown="block"> 

### Tutorial

Installation guides exist for users and developers.

- [Install for users](tutorial/install_user.md)
- [Install for developers](tutorial/install_devs.md)
- [Compile the documentation](tutorial/compile_docs.md)

</div>
<div markdown="block">

### How-to guides

<!-- How-to guides provide step-by-step instructions for a wide range of tasks, with the overarching topics:-->

</div>

<div markdown="block">

### Learn

Background knowledge to specific topics.

- [Exchange](explanation/learn.md)
- [Provenance](explanation/provenance.md)
- [Specifications](explanation/suggestions.md)
- [NeXus NXapm](explanation/nxapm.md)

</div>
<div markdown="block">

### Reference

<!-- ONE PURPOSE SENTENCE -->

</div>
</div>

<h2>Project and community</h2>

For questions or suggestions:

- Open an issue on the repository via [GitHub](https://github.com/atomprobe-tc/ifes_apt_tc_data_modeling/issues).

[The work is supported by the International Field Emission Society (IFES) Atom Probe Tomography Technical Committee (APT TC).](https://fieldemission.org/article.php?id=technical_committee)

[The work is funded by the Deutsche Forschungsgemeinschaft (DFG, German Research Foundation) - 460197019 (FAIRmat).](https://gepris.dfg.de/gepris/projekt/460197019?language=en)

[The library is used for the pynxtools-apm to standardized atom probe data using NeXus.](https://www.github.com/FAIRmat-NFDI/pynxtools-apm.git)
